@@ -16,7 +16,19 @@ logger = logging.getLogger(__name__)
 
 class ExecutorFactory(common.loggable):
     """
-    Factory to create an executor.
+    Factory responsible to create
+    an :class:`twitter_monitor.core.Executor` instance.
+
+    :param routines: A list of :class:`twitter_monitor.core.Routine`
+        subclasses (**not instances**)
+    :param twitter_keys: A dictionary with api twitter keys. It must have these
+        keys (you can manage all of them on https://apps.twitter.com/).
+
+        - consumer_key
+        - consumer_secret
+        - access_token_key
+        - access_token_secret
+    :param setup_default_logger: If True (default) it'll setup the root logger.
     """
 
     def __init__(self, routines,
@@ -26,8 +38,12 @@ class ExecutorFactory(common.loggable):
         self.setup_default_logger = setup_default_logger
 
     def create_default(self):
+        """
+        Create a default Executor and setup a default logger.
+        """
+
         self._setup_logger()
-        self.logger.debug("Creating a default Executor")
+        self.logger.debug(u"Creating a default Executor")
 
         notifier = self._create_notifier(self._create_twitter_api())
 
@@ -38,13 +54,14 @@ class ExecutorFactory(common.loggable):
 
     def _setup_logger(self):
         """
-        Setup module logger to
+        Setup module logger to show processing messages.
         """
+
         if not self.setup_default_logger:
             return
 
         formatter = logging.Formatter(
-            '%(asctime)s - %(levelname)s - %(message)s')
+            u'%(asctime)s - %(levelname)s - %(message)s')
 
         handler = logging.StreamHandler()
         handler.setFormatter(formatter)
@@ -54,14 +71,14 @@ class ExecutorFactory(common.loggable):
         logger.setLevel(logging.DEBUG)
 
     def _create_twitter_api(self):
-        self.logger.debug("Creating a twitter api")
+        self.logger.debug(u"Creating a twitter api")
 
         ta = self.twitter_keys
 
-        self.logger.debug("Consumer_key: " + ta["consumer_key"])
-        self.logger.debug("Consumer_secret: " + ta["consumer_secret"])
-        self.logger.debug("Access_token_key: " + ta["access_token_key"])
-        self.logger.debug("Access_token_secret: " + ta["access_token_secret"])
+        self.logger.debug(u"Consumer_key: " + ta["consumer_key"])
+        self.logger.debug(u"Consumer_secret: " + ta["consumer_secret"])
+        self.logger.debug(u"Access_token_key: " + ta["access_token_key"])
+        self.logger.debug(u"Access_token_secret: " + ta["access_token_secret"])
 
         auth = tweepy.OAuthHandler(
             ta['consumer_key'], ta['consumer_secret'])
@@ -87,7 +104,17 @@ class ExecutorFactory(common.loggable):
 
 class Executor(common.loggable):
     """
-    Responsable to run routines
+    Responsible to run routines. This class must receive
+    an instance of :class:`twitter_monitor.core.Notifier` class
+    and an array of routines.
+
+    :param notifier: An instance of :class:`twitter_monitor.core.Notifier`
+    :param routines: A list of :class:`twitter_monitor.core.Routine`
+        subclasses (**not instances**)
+    :param key_value_store: A dictionary like storage.
+        It is used to store info about last
+        executions (like last execution time).
+        It is usual to use a simple key store like *anydbm*.
     """
 
     def __init__(self, notifier, routines, key_value_store={}):
@@ -97,6 +124,11 @@ class Executor(common.loggable):
         self._routines_instances = None
 
     def run(self):
+        """
+        Execute all routines. It returns True if all routines are
+        executed with success.
+        """
+
         success = True
 
         try:
@@ -115,12 +147,16 @@ class Executor(common.loggable):
                     and callable(getattr(self.key_value_store, "close"))):
                     self.key_value_store.close()
 
-            self.logger.error("Error: " + e.message)
+            self.logger.error("Error: " + str(e))
             success = False
 
         return success
 
     def routines_instances(self):
+        """
+        Instantiate and return all routines instances.
+        """
+
         if self._routines_instances is not None:
             return self._routines_instances
 
@@ -136,6 +172,8 @@ class Executor(common.loggable):
 class Notifier(common.loggable):
     """
     It sends a message to destinations (followers) with twitter API.
+
+    :param api: An API instance (for now, we are using Tweepy)
     """
 
     def __init__(self, api):
@@ -145,18 +183,24 @@ class Notifier(common.loggable):
         self._followers = None
 
     def send(self, message):
-        self.logger.debug("Message to send: \"{}\"".format(message))
+        """
+        Send a message to all destinations
 
-        # Casting message
-        message = str(message)
+        :param message: A message to send to all followers. **USE UNICODE**
+        """
+
+        if not isinstance(message, unicode):
+            message = unicode(message, errors="ignore")
+
+        self.logger.debug(u"Message to send: \"{}\"".format(message))
 
         if len(message.strip()) == 0:
             # @todo - Change this to exception
-            self.logger.warn("Empty message")
+            self.logger.warn(u"Empty message")
             return
 
         for follower in self._get_followers():
-            self.logger.info("Sending message to \"{}\": \"{}\"".format(
+            self.logger.info(u"Sending message to \"{}\": \"{}\"".format(
                 follower.screen_name, message))
 
             self._api.send_direct_message(user_id=follower.id, text=message)
@@ -171,17 +215,23 @@ class Notifier(common.loggable):
 class Routine(common.loggable):
     """
     Routine representation
+
+    :param notifier: An instance of :class:`twitter_monitor.core.Notifier`
+    :param key_value_store: A dictionary like storage.
+        It is used to store info about last
+        executions (like last execution time).
+        It is usual to use a simple key store like *anydbm*.
     """
 
     __metaclass__ = ABCMeta
 
-    name = None  # Routine full name
+    name = None  #: Routine full name. **ALWAYS USE UNICODE**
 
-    short_name = None  # Routine short name (it'll be used in message)
+    short_name = None  #: Routine short name (it'll be used in the message). **ALWAYS USE UNICODE**
 
-    interval_minutes = None  # Interval to execute routine
+    interval_minutes = None  #: Interval (in minutes) to execute routine
 
-    _file_last_execution = None  # Cache of last execution file content
+    _file_last_execution = None  #: Cache of last execution file content
 
     def __init__(self, notifier, key_value_store={}):
         self.notifier = notifier
@@ -199,7 +249,7 @@ class Routine(common.loggable):
         """
 
         if self._skip_execution():
-            self.logger.info("Skipping execution")
+            self.logger.info(u"Skipping execution")
             return True
 
         if self._execute():
@@ -217,7 +267,7 @@ class Routine(common.loggable):
         diff = datetime.datetime.now() - self.last_execution
 
         if diff < timedelta_compare:
-            message = ("Interval not reached. Elapsed {} minutes")
+            message = u"Interval not reached. Elapsed {} minutes"
             self.logger.info(message.format(diff.seconds/60))
             return True
 
@@ -228,6 +278,9 @@ class Routine(common.loggable):
         """
         Put your code here in your subclasses.
         Must be implemented by subclasses.
+
+        Use self.notify(u"Some message") to send a message to recepients.
+        **IMPORTANT: Always use UNICODE messages**
         """
 
         return NotImplemented
@@ -245,7 +298,7 @@ class Routine(common.loggable):
         Returns a datetime object with last execution of routine
         """
 
-        self.logger.debug("Finding last execution time")
+        self.logger.debug(u"Finding last execution time")
 
         try:
             if self.uid in self.key_value_store:
@@ -253,7 +306,7 @@ class Routine(common.loggable):
                 return datetime.datetime.strptime(val, "%Y-%m-%d %H:%M:%S.%f")
         except Exception, e:
             self.logger.debug(
-                "Exception - Method/property 'last_execution': " + e.message)
+                "Exception - Method/property 'last_execution': " + str(e))
 
         return None
 
@@ -269,23 +322,27 @@ class Routine(common.loggable):
     @property
     def uid(self):
         """
-        It returns the routine unique id
+        Routine unique id (md5 format)
         """
+
         name = u"{} {} {}".format(
-            self.__class__.__name__,
-            self.name.encode("ascii", "ignore"),
-            self.short_name.encode("ascii", "ignore"))
+            self.__class__.__name__, self.name, self.short_name)
 
         m = hashlib.md5()
-        m.update(name)
+        m.update(name.encode("ascii", errors="ignore"))
 
         return m.hexdigest()
 
     def notify(self, message):
-        message = str(message)
+        """
+        Send the message
+        """
+
+        if not isinstance(message, unicode):
+            message = unicode(message)
 
         if len(message.strip()) == 0:
-            self.logger.debug("Empty message")
+            self.logger.debug(u"Empty message")
             return
 
         new_message = u"{}: {}".format(
